@@ -1,9 +1,3 @@
-#ifdef HAVE_CONFIG_H
-#include "config.h"
-#else
-#include "config.h.in"
-#endif
-
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
@@ -287,9 +281,6 @@ RB_Generate_Doc_Start (
 	
 	/* changed default header to use boldface (vs slant) */
 	fprintf (dest_doc, "\\pagestyle{headings}\n");
-	// fprintf (dest_doc, 
-	// "\\markright{\\bf \\protect\\thesection \\hskip 1em"
-	// "\\relax API Reference}\n\n");
 
 	if (document_title) {
 	  fprintf (dest_doc, "\\title{%s}\n", 
@@ -301,16 +292,12 @@ RB_Generate_Doc_Start (
 	fprintf (dest_doc, "\\makeindex\n");
 	fprintf (dest_doc, "\\begin{document}\n");
 	fprintf (dest_doc, "\\maketitle\n");
-	// fprintf (dest_doc, "\\section{API Reference}\n"
-	//	 "This section is your complete reference to the "
-	//	 "functions and concepts for this system.\n");
 	/* autogenerate table of contents! */
  	fprintf (dest_doc, "\\printindex\n");
 	fprintf (dest_doc, "\\tableofcontents\n");
 	fprintf (dest_doc, "\\newpage\n");
-	
 	/* trick to disable the autogenerated \newpage */
-	fprintf (dest_doc, "%\n");
+	fprintf (dest_doc, "\n");
       }
       break;
 
@@ -424,7 +411,6 @@ RB_Generate_Doc_End (FILE * dest_doc, char *name)
       break;
     case LATEX:
       if (!(course_of_action & DO_SINGLEDOC)) { 
-	// 	fprintf (dest_doc, "\\newpage\n\\printindex\n");
 	fprintf (dest_doc, "\\end{document}\n");
       }
       break;
@@ -859,6 +845,10 @@ RB_Generate_Item_Body (FILE * dest_doc, char *dest_name,
 
       if (item_type != SOURCE_ITEM)
 	{
+          /* Skip empty lines */
+          while (*cur_char == '\n') {
+                cur_char++;
+          }
 	  cur_char = RB_Skip_Remark_Marker (cur_char);
 	}
       else
