@@ -1,9 +1,3 @@
-#ifdef HAVE_CONFIG_H
-#include "config.h"
-#else
-#include "config.h.in"
-#endif
-
 /****h* Autodoc/ROBODoc [3.2]
  * NAME
  *   ROBODoc -- AutoDoc formatter
@@ -262,6 +256,17 @@
  *        the master index file.
  *      o Made the search for headermarkers case insensitve.
  *        REM == Rem == rem  
+ *    July 2000 - V3.2.3
+ *      o Fixed a bug that caused links of the type
+ *        "someword/anotherword," to be ignored, while
+ *        "someword/anotherword" was recognized.
+ *    Sep 2000 
+ *      o Labels with identical names are now numbered.
+ *    Apr 2001
+ *      o The source file is opened "rb" this I hope will
+ *        make it possible to use Robodoc under windows.
+ *        (Thanks to Carlo Caminati) 
+ *
  * NOTES
  *   Has been succesfully compiled:
  *     On an Amiga with SAS/C, DICE C and gcc (Amiga 1200)
@@ -269,7 +274,7 @@
  *     On a Dec Alpha Station
  *     Under HP/UX on a HP9000/800
  *     Under IRIX
- *     On a Linux box with gcc.  Slackware, Redhat, and Debian 2.1.
+ *     On a Linux box with gcc, Slackware, Redhat, and Debian 2.1.
  * BUGS
  *   - HTML output is not Lynx friendly -- attributes are applied
  *     to leading white space =P ... solution: fix Lynx  >=)
@@ -299,9 +304,9 @@
 #include "generator.h"
 
 #ifdef _AMIGA
-char RB_VER[] = "\0$VER: robodoc " VERSION " " __AMIGADATE__ " (c) by Maverick Software Development 1994-1999";
+char RB_VER[] = "\0$VER: robodoc " VERSION " " __AMIGADATE__ " (c) by Maverick Software Development 1994-2001";
 #else
-char RB_VER[] = "$VER: robodoc " VERSION " (" __DATE__ ") (c) by Maverick Software Development 1994-1999";
+char RB_VER[] = "$VER: robodoc " VERSION " (" __DATE__ ") (c) by Maverick Software Development 1994-2001";
 #endif
 
 
@@ -417,8 +422,8 @@ int line_number = 0;
  */
 
 char use[] =
-"ROBODoc v" VERSION ", autodocs formatter ($Revision: 1.5 $)\n"
-"(c) 1994-2000 Frans Slothouber and Jacco van Weert\n"
+"ROBODoc Version " VERSION ", autodocs formatter ($Revision: 1.7 $)\n"
+"(c) 1994-2001 Frans Slothouber and Jacco van Weert\n"
 "robodoc comes with ABSOLUTELY NO WARRANTY.\n"
 "This is free software, and you are welcome to redistribute it\n"
 "under certain conditions; type `robodoc -c' for details.\n"
@@ -560,12 +565,14 @@ main (int argc, char **argv)
       RB_Analyse_Defaults_File ();
 
       RB_Say ("trying to open source file \"%s\"\n", argv[1]);
-      if ((source = fopen (argv[1], "r")) != NULL)
+      if ((source = fopen (argv[1], "rb")) != NULL)
 	{
 	  if (!(course_of_action & DO_INDEX))
 	    {
 	      RB_Say ("analysing source file \"%s\"\n", argv[1]);
 	      RB_Analyse_Document (source);
+              RB_Number_Duplicate_Headers();
+
 	      if (course_of_action & DO_SORT)
 		{
 		  RB_Say ("sorting headers\n");
